﻿param (
    [Parameter(Mandatory)]
    [Int[]]$NotifyInterval,
    [Parameter(Mandatory)]
    [String]$From,
    [Parameter(Mandatory)]
    [String]$SmtpServer,
    [Parameter(Mandatory)]
    [String]$EmailTemplate
)

# Get the content from our Email Template so that we can manipulate it later
$EmailTemplate = Get-Content -Path $EmailTemplate

# Get all AD users who are enabled and have passwords which are set to expire
$Users = Get-ADUser -filter {Enabled -eq $True -and PasswordNeverExpires -eq $False} –Properties "DisplayName", "EmailAddress", "msDS-UserPasswordExpiryTimeComputed"
$Today = Get-Date

foreach ($User in $Users){
    $ExpiryDate = [datetime]::FromFileTime($User.'msDS-UserPasswordExpiryTimeComputed')
    $DaysToExpiry = ($ExpiryDate - $Today).Days

    # Check if the number of days until the user's password expires is in the list of days to notify.
    if ($DaysToExpiry -in $NotifyInterval) {

        $Subject = "Password expires in $DaysToExpiry day(s)"
        $Body = $EmailTemplate.Replace("{DISPLAYNAME}",$User.DisplayName).Replace("{DATE}",$ExpiryDate).Replace("{DAYS}",$DaysToExpiry)

        Send-MailMessage -To $User.EmailAddress -Subject $Subject -From $From -SmtpServer $SmtpServer -BodyAsHtml $Body -UseSsl
    }
}